@@ -12,7 +12,9 @@ from .object_unpacker import recursively_get_all_subobjects_in_object
 
 
 def create_graph_of_module(
-    module: types.ModuleType, include_external_dependencies: bool = True
+    module: types.ModuleType,
+    include_external_dependencies: bool = True,
+    strict_mode: bool = True,
 ) -> Graph:
     all_objects = frozenset(recursively_get_all_subobjects_in_object(module))
     nodes = set(
@@ -20,18 +22,11 @@ def create_graph_of_module(
         for obj in all_objects
         for node in {create_node_from_object(obj)}
         | get_dependency_nodes_with_parents(
-            obj, include_external_dependencies=include_external_dependencies
+            obj,
+            include_external_dependencies=include_external_dependencies,
+            strict_mode=strict_mode,
         )
     )
-    print(
-        {
-            node.identifier
-            for node in nodes
-            if "domain" in node.name
-            or "domain" in node.identifier
-            or "domain" in (node.parent_identifier or "")
-        }
-    )
     edges = set(
         Dependency(
             from_node=get_identifier_of_object(obj),
@@ -39,7 +34,9 @@ def create_graph_of_module(
         )
         for obj in all_objects
         for dependency in get_dependency_nodes(
-            obj, include_external_dependencies=include_external_dependencies
+            obj,
+            include_external_dependencies=include_external_dependencies,
+            strict_mode=strict_mode,
         )
     )
     return Graph(nodes=nodes, edges=edges)
